-- ******************************************************************************
-- * ORIGINAL DESIGN
-- ******************************************************************************
-- * FILE: jesd204b_eval_top.vhd
-- *
-- * AUTHOR: Andreas Rytlig
-- *
-- * Designed by Zeuxion, 2013.
-- *
-- *
-- * OVERVIEW:
-- *
-- * Wrapper for the evaluation core for JESD204B. Target is an Arria V GT board.
-- *
-- * Note: The board only has 2 SFP+ interfaces. The external clock synthesizer
-- * needs to be programmed with the Altera Clock tool to 150 MHz at REFCLK2_A_QL1_P.
-- * When using the clock tool, set environment variables in windows to point to a
-- * Quartus 12.1 installation!!!
-- *
-- * TBD: NIOS Interrupt
-- *
-- ******************************************************************************
-- * MODIFIED
-- ******************************************************************************
-- * DATE: 05/12/2014
-- *
-- * By Dallas Logic Corpoation 
-- *
-- * OVERVIEW:
-- *
-- * The original design was modified to provide JESD204B support for Arrow's SOCkit 
-- * development board. The Sockit developemnt board is capable of 4 lanes,
-- * with each lane able to support 3.125Gbps. While the design is capable of supporting
-- * the higher data rate, the current design only supports 1.0Gbps. At 1.0Gbps
-- * the ADC sample rate is 50Msps. The onchip ARM processor is used to configure both
-- * the ADC34J22 and the LMK04828B located on the ADC module. The devices are configured 
-- * via a SPI interface.
-- *
-- *******************************************************************************
-- *******************************************************************************
-- SOCkit to DEV-ADC01 (JESD204B HSMC Module) Pin Mapping
----------------------------------------------------------------------------------
-- ---Module Signal Name---HSMC CON. Pin---SOCkit Signal Name---SOCkit FPGA Pin---
----------------------------------------------------------------------------------
-- Bank 1
--    HSMC_GXB_RX0_P		     30					HSMC_GXB_RX_p0		     AE2				
--    HSMC_GXB_RX0_N		     32					HSMC_GXB_RX_n0			  AE1			
--    HSMC_GXB_RX1_P		     26					HSMC_GXB_RX_p1			  AC2			
--    HSMC_GXB_RX1_N		     28					HSMC_GXB_RX_n1			  AC1			
--    HSMC_GXB_RX2_P		     22					HSMC_GXB_RX_p2			  AA2			
--    HSMC_GXB_RX2_N		     24					HSMC_GXB_RX_n2			  AA1			
--    HSMC_GXB_RX3_P		     18					HSMC_GXB_RX_p3			  W2			
--    HSMC_GXB_RX3_N		     20					HSMC_GXB_RX_n3			  W1	

--    GX Reference clock / Device clock		
--    HSMC_DEVCLK_P          14					HSMC_GXB_RX_p4			  U2			
--    HSMC_DEVCLK_N	        16					HSMC_GXB_RX_n4			  U1			

-- Bank 2
--    LMK_MOSI		           47					HSMC_TX_p0		        A9		
--    LMK_SCLK		           53					HSMC_TX_p1				  E8
--    LMK_SSN		           59					HSMC_TX_p2				  G7
--    LMK_SYNC		           65					HSMC_TX_p3				  D6
--    LMK_MISO               48			      HSMC_RX_p0				  G12
--    ADS_MOSI		           71					HSMC_TX_p4				  D5
--    ADS_SCLK		           77					HSMC_TX_p5				  E3
--    ADS_SSN		           83					HSMC_TX_p6				  E4
--    ADS_PDN		           89					HSMC_TX_p7			     C3	
--    ADS_MISO               54			      HSMC_RX_p1             K12

--    HSMC_SYSREF_P			  60              HSMC_RX_p2             G10
--    HSMC_SYSREF_N			  62              HSMC_RX_n2             F10

--    OVR_CH0					  66					HSMC_RX_p3             J10
--    OVR_CH1					  72					HSMC_RX_p4             K7
--    OVR_CH2					  78					HSMC_RX_p5             J7
--    OVR_CH3					  84					HSMC_RX_p6             H8
--(spare sysref)
--    HSMC_CLKIN1_P			  96              HSMC_CLKIN_p1 			  AA26
--    HSMC_CLKIN1_N			  98              HSMC_CLKIN_n1 			  AB27

-- Bank 3
--    ADS_RESET		        101					HSMC_TX_p8				  E1
			
--    ADS_SYNC_P	           107					HSMC_TX_p9				  D2
--    ADS_SYNC_N		        109					HSMC_TX_n9				  C2

--    TRIGGER_IN  			  113					HSMC_TX_p10            B2
--(spare device clk)
--    HSMC_CLKIN2_P			  156             HSMC_CLKIN_p2 			  H15
--    HSMC_CLKIN2_N			  158             HSMC_CLKIN_n2          G15
----------------------------------------------------------------------------------
--********************************************************************************
library ieee;
use ieee.std_logic_1164.all;
use IEEE.numeric_std.all;
use work.ieee_ext.all;

entity jesd204b_eval_hsmc_c5_top is
  port (
  
--*********** START ARM SYSTEM SIGNALS ******************  
--*********** DDR3 Memory Interface ***************			
	   memory_mem_a   	: out STD_LOGIC_VECTOR(14 downto 0);                          
		memory_mem_ba  	: out STD_LOGIC_VECTOR(2 downto 0);                         
		memory_mem_ck  	: out STD_LOGIC;                       
		memory_mem_ck_n	: out STD_LOGIC;                        
		memory_mem_cke		: out STD_LOGIC;                        
		memory_mem_cs_n	: out STD_LOGIC;                       
		memory_mem_ras_n	: out STD_LOGIC;                       
		memory_mem_cas_n	: out STD_LOGIC;                       
		memory_mem_we_n	: out STD_LOGIC;                        
		memory_mem_reset_n: out STD_LOGIC;                    
		memory_mem_dq 		: inout STD_LOGIC_VECTOR(31 downto 0);                            
		memory_mem_dqs		: inout STD_LOGIC_VECTOR(3 downto 0);                          
		memory_mem_dqs_n	: inout STD_LOGIC_VECTOR(3 downto 0);                       
		memory_mem_odt		: out STD_LOGIC;                        
		memory_mem_dm		: out STD_LOGIC_VECTOR(3 downto 0);                        
		memory_oct_rzqin	: in STD_LOGIC;   
--*********** Ethernet Interface ******************			
		hps_emac1_TX_CLK	: out STD_LOGIC;     
		hps_emac1_TXD0		: out STD_LOGIC;      
		hps_emac1_TXD1		: out STD_LOGIC;       
		hps_emac1_TXD2		: out STD_LOGIC;       
		hps_emac1_TXD3		: out STD_LOGIC;     
		hps_emac1_RXD0		: in STD_LOGIC; 
		hps_emac1_MDIO		: inout STD_LOGIC;   
		hps_emac1_MDC		: out STD_LOGIC;   
		hps_emac1_RX_CTL	: in STD_LOGIC; 
		hps_emac1_TX_CTL	: out STD_LOGIC; 
		hps_emac1_RX_CLK	: in STD_LOGIC; 
		hps_emac1_RXD1		: in STD_LOGIC;  
		hps_emac1_RXD2		: in STD_LOGIC;  
		hps_emac1_RXD3		: in STD_LOGIC; 
--*********** Quad SPI CFG Interface **************		
		hps_qspi_IO0		: inout STD_LOGIC;    
		hps_qspi_IO1		: inout STD_LOGIC;   
		hps_qspi_IO2		: inout STD_LOGIC;   
		hps_qspi_IO3		: inout STD_LOGIC;   
		hps_qspi_SS0		: out STD_LOGIC;    
		hps_qspi_CLK		: out STD_LOGIC; 
--*********** MicroSD Interface *******************		
		hps_sdio_CMD		: inout STD_LOGIC;     
		hps_sdio_D0			: inout STD_LOGIC;     
		hps_sdio_D1			: inout STD_LOGIC;      
		hps_sdio_CLK		: out STD_LOGIC;     
		hps_sdio_D2			: inout STD_LOGIC;       
		hps_sdio_D3			: inout STD_LOGIC; 
--*********** USB Interface *******************	      
		hps_usb1_D0			: inout STD_LOGIC;       
		hps_usb1_D1			: inout STD_LOGIC;       
		hps_usb1_D2			: inout STD_LOGIC;      
		hps_usb1_D3			: inout STD_LOGIC;       
		hps_usb1_D4			: inout STD_LOGIC;
      hps_usb1_D5			: inout STD_LOGIC;       		
		hps_usb1_D6			: inout STD_LOGIC;       
		hps_usb1_D7			: inout STD_LOGIC;      
		hps_usb1_CLK		: in STD_LOGIC;    
		hps_usb1_STP		: out STD_LOGIC;    
		hps_usb1_DIR		: in STD_LOGIC;    
		hps_usb1_NXT		: in STD_LOGIC;
--*********** LTC I2C/SPI Connector ***********	    		
		hps_spim0_CLK		: out STD_LOGIC;   
		hps_spim0_MOSI		: out STD_LOGIC;   
		hps_spim0_MISO		: in STD_LOGIC;    
		hps_spim0_SS0		: out STD_LOGIC; 
--*********** LCD SPI Interface ***************	    		
		hps_spim1_CLK		: out STD_LOGIC;   
		hps_spim1_MOSI		: out STD_LOGIC;   
		hps_spim1_MISO		: in STD_LOGIC;    
		hps_spim1_SS0		: out STD_LOGIC;
--*********** RS232 Interface *****************			
		hps_uart0_RX		: in STD_LOGIC;     
		hps_uart0_TX		: out STD_LOGIC;
--*********** SI5338 CLock Interface **********				
		hps_i2c1_SDA		: inout STD_LOGIC;       
		hps_i2c1_SCL		: inout STD_LOGIC;  
--***********LED Interface *****************		
		hps_gpio_GPIO53	: inout STD_LOGIC;   
		hps_gpio_GPIO54	: inout STD_LOGIC;   
		hps_gpio_GPIO55	: inout STD_LOGIC;   
		hps_gpio_GPIO56	: inout STD_LOGIC;  
--*********** MISC Interface *****************				
		hps_gpio_GPIO00	: inout STD_LOGIC;    
		hps_gpio_GPIO09	: inout STD_LOGIC;   
		hps_gpio_GPIO35	: inout STD_LOGIC;  
		hps_gpio_GPIO48	: inout STD_LOGIC;   		
		hps_gpio_GPIO61	: inout STD_LOGIC;    
		hps_gpio_GPIO62	: inout STD_LOGIC;   	 
--*********** END ARM SYSTEM SIGNALS ******************  
--*********** START JESD204B SIGNALS ******************  

         -- 2.5V CPU Reset Pushbutton (TR=0)
	 
	 
	 --JESD Control Interface ADC & LMK Control-----------------------------------
	 LMK_MISO          : in  std_logic;                          -- lmk04826_spi_external.MISO
	 LMK_MOSI          : out std_logic;                          -- lmk04826_spi_external_MOSI                                        
    LMK_SCLK          : out std_logic;                          -- lmk04826_spi_external_SCLK                                        
    LMK_SSN           : out std_logic;                          -- lmk04826_spi_external_SS_n 
    LMK_SYNC          : out std_logic;                          -- lmk04826_spi_external_SYNC 	 
    ADS_MISO          : in std_logic;                           -- ads34j45_spi_external_MISO
    ADS_MOSI          : out std_logic;                          -- ads34j45_spi_external_MOSI
    ADS_SCLK          : out std_logic;                          -- ads34j45_spi_external_SCLK                                       
    ADS_SSN           : out std_logic;                          -- ads34j45_spi_external_SS_n
	 ADS_PDN           : out std_logic;                          -- ads34j45_spi_external_PDN
	 ADS_RESET         : out std_logic;                          -- ads34j45 RESET
	 ADS_SYNC_P        : out std_logic;                          -- ads34j45 SYNC
    OVR_CH0				 : in std_logic;  								 -- ads34j45  CH0 Over range
    OVR_CH1				 : in std_logic;  								 -- ads34j45  CH1 Over range  
    OVR_CH2				 : in std_logic;  								 -- ads34j45  CH2 Over range  
    OVR_CH3				 : in std_logic;  								 -- ads34j45  CH3 Over range  
	 
	 TRIGGER_IN        : in std_logic;  								 -- HSMC module Trigger Input
	 -- Miscellaneous------------------------//16 pins //--------------------------

    user1_dipsw       : in  std_logic_vector(7 downto 0);     	 -- 2.5V User DIP Switches (TR=0)
	 user1_leds        : out std_logic_vector(3 downto 0);
    user1_pb          : in  std_logic_vector(2 downto 0);     	 -- 2.5V User Pushbuttons (TR=0)
    cpu1_resetn       : in  std_logic;                     
	 --HSMC ------------------------------//16 pins //--------------------------
	 clk_bot1          : in  std_logic;                          -- 1.5V    //50 MHz ajustable from SiLabs SI5338

	 HSMC_DEVCLK_P     : in  std_logic;                          -- Device Clock from LMK 
--	 HSMC_DEVCLK_N     : in  std_logic;                          -- Device Clock from LMK  
	 HSMC_SYSREF_P     : in  std_logic; 
	 HSMC_CLKIN1_P     : in  std_logic; 								 -- Spare SYSREF, Unused in current design
	 HSMC_CLKIN2_P     : in  std_logic; 								 -- Spare DEVCLK, Unused in current design
	 HSMC_GXB_RX0_P    : in  std_logic;
	 HSMC_GXB_RX1_P    : in  std_logic;
	 HSMC_GXB_RX2_P    : in  std_logic;
	 HSMC_GXB_RX3_P    : in  std_logic
	 
  );
end jesd204b_eval_hsmc_c5_top;


architecture rtl of jesd204b_eval_hsmc_c5_top is

-----------------------------------------------------------------------------------------------------------------
    component soc_system is
        port (
            clk_clk                                           : in    std_logic                     := 'X';             -- clk
            reset_reset_n                                     : in    std_logic                     := 'X';             -- reset_n
            memory_mem_a                                      : out   std_logic_vector(14 downto 0);                    -- mem_a
            memory_mem_ba                                     : out   std_logic_vector(2 downto 0);                     -- mem_ba
            memory_mem_ck                                     : out   std_logic;                                        -- mem_ck
            memory_mem_ck_n                                   : out   std_logic;                                        -- mem_ck_n
            memory_mem_cke                                    : out   std_logic;                                        -- mem_cke
            memory_mem_cs_n                                   : out   std_logic;                                        -- mem_cs_n
            memory_mem_ras_n                                  : out   std_logic;                                        -- mem_ras_n
            memory_mem_cas_n                                  : out   std_logic;                                        -- mem_cas_n
            memory_mem_we_n                                   : out   std_logic;                                        -- mem_we_n
            memory_mem_reset_n                                : out   std_logic;                                        -- mem_reset_n
            memory_mem_dq                                     : inout std_logic_vector(31 downto 0) := (others => 'X'); -- mem_dq
            memory_mem_dqs                                    : inout std_logic_vector(3 downto 0)  := (others => 'X'); -- mem_dqs
            memory_mem_dqs_n                                  : inout std_logic_vector(3 downto 0)  := (others => 'X'); -- mem_dqs_n
            memory_mem_odt                                    : out   std_logic;                                        -- mem_odt
            memory_mem_dm                                     : out   std_logic_vector(3 downto 0);                     -- mem_dm
            memory_oct_rzqin                                  : in    std_logic                     := 'X';             -- oct_rzqin
            hps_0_hps_io_hps_io_emac1_inst_TX_CLK             : out   std_logic;                                        -- hps_io_emac1_inst_TX_CLK
            hps_0_hps_io_hps_io_emac1_inst_TXD0               : out   std_logic;                                        -- hps_io_emac1_inst_TXD0
            hps_0_hps_io_hps_io_emac1_inst_TXD1               : out   std_logic;                                        -- hps_io_emac1_inst_TXD1
            hps_0_hps_io_hps_io_emac1_inst_TXD2               : out   std_logic;                                        -- hps_io_emac1_inst_TXD2
            hps_0_hps_io_hps_io_emac1_inst_TXD3               : out   std_logic;                                        -- hps_io_emac1_inst_TXD3
            hps_0_hps_io_hps_io_emac1_inst_RXD0               : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD0
            hps_0_hps_io_hps_io_emac1_inst_MDIO               : inout std_logic                     := 'X';             -- hps_io_emac1_inst_MDIO
            hps_0_hps_io_hps_io_emac1_inst_MDC                : out   std_logic;                                        -- hps_io_emac1_inst_MDC
            hps_0_hps_io_hps_io_emac1_inst_RX_CTL             : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RX_CTL
            hps_0_hps_io_hps_io_emac1_inst_TX_CTL             : out   std_logic;                                        -- hps_io_emac1_inst_TX_CTL
            hps_0_hps_io_hps_io_emac1_inst_RX_CLK             : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RX_CLK
            hps_0_hps_io_hps_io_emac1_inst_RXD1               : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD1
            hps_0_hps_io_hps_io_emac1_inst_RXD2               : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD2
            hps_0_hps_io_hps_io_emac1_inst_RXD3               : in    std_logic                     := 'X';             -- hps_io_emac1_inst_RXD3
            hps_0_hps_io_hps_io_qspi_inst_IO0                 : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO0
            hps_0_hps_io_hps_io_qspi_inst_IO1                 : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO1
            hps_0_hps_io_hps_io_qspi_inst_IO2                 : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO2
            hps_0_hps_io_hps_io_qspi_inst_IO3                 : inout std_logic                     := 'X';             -- hps_io_qspi_inst_IO3
            hps_0_hps_io_hps_io_qspi_inst_SS0                 : out   std_logic;                                        -- hps_io_qspi_inst_SS0
            hps_0_hps_io_hps_io_qspi_inst_CLK                 : out   std_logic;                                        -- hps_io_qspi_inst_CLK
            hps_0_hps_io_hps_io_sdio_inst_CMD                 : inout std_logic                     := 'X';             -- hps_io_sdio_inst_CMD
            hps_0_hps_io_hps_io_sdio_inst_D0                  : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D0
            hps_0_hps_io_hps_io_sdio_inst_D1                  : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D1
            hps_0_hps_io_hps_io_sdio_inst_CLK                 : out   std_logic;                                        -- hps_io_sdio_inst_CLK
            hps_0_hps_io_hps_io_sdio_inst_D2                  : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D2
            hps_0_hps_io_hps_io_sdio_inst_D3                  : inout std_logic                     := 'X';             -- hps_io_sdio_inst_D3
            hps_0_hps_io_hps_io_usb1_inst_D0                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D0
            hps_0_hps_io_hps_io_usb1_inst_D1                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D1
            hps_0_hps_io_hps_io_usb1_inst_D2                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D2
            hps_0_hps_io_hps_io_usb1_inst_D3                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D3
            hps_0_hps_io_hps_io_usb1_inst_D4                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D4
            hps_0_hps_io_hps_io_usb1_inst_D5                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D5
            hps_0_hps_io_hps_io_usb1_inst_D6                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D6
            hps_0_hps_io_hps_io_usb1_inst_D7                  : inout std_logic                     := 'X';             -- hps_io_usb1_inst_D7
            hps_0_hps_io_hps_io_usb1_inst_CLK                 : in    std_logic                     := 'X';             -- hps_io_usb1_inst_CLK
            hps_0_hps_io_hps_io_usb1_inst_STP                 : out   std_logic;                                        -- hps_io_usb1_inst_STP
            hps_0_hps_io_hps_io_usb1_inst_DIR                 : in    std_logic                     := 'X';             -- hps_io_usb1_inst_DIR
            hps_0_hps_io_hps_io_usb1_inst_NXT                 : in    std_logic                     := 'X';             -- hps_io_usb1_inst_NXT
            hps_0_hps_io_hps_io_spim0_inst_CLK                : out   std_logic;                                        -- hps_io_spim0_inst_CLK
            hps_0_hps_io_hps_io_spim0_inst_MOSI               : out   std_logic;                                        -- hps_io_spim0_inst_MOSI
            hps_0_hps_io_hps_io_spim0_inst_MISO               : in    std_logic                     := 'X';             -- hps_io_spim0_inst_MISO
            hps_0_hps_io_hps_io_spim0_inst_SS0                : out   std_logic;                                        -- hps_io_spim0_inst_SS0
            hps_0_hps_io_hps_io_spim1_inst_CLK                : out   std_logic;                                        -- hps_io_spim1_inst_CLK
            hps_0_hps_io_hps_io_spim1_inst_MOSI               : out   std_logic;                                        -- hps_io_spim1_inst_MOSI
            hps_0_hps_io_hps_io_spim1_inst_MISO               : in    std_logic                     := 'X';             -- hps_io_spim1_inst_MISO
            hps_0_hps_io_hps_io_spim1_inst_SS0                : out   std_logic;                                        -- hps_io_spim1_inst_SS0
            hps_0_hps_io_hps_io_uart0_inst_RX                 : in    std_logic                     := 'X';             -- hps_io_uart0_inst_RX
            hps_0_hps_io_hps_io_uart0_inst_TX                 : out   std_logic;                                        -- hps_io_uart0_inst_TX
            hps_0_hps_io_hps_io_i2c1_inst_SDA                 : inout std_logic                     := 'X';             -- hps_io_i2c1_inst_SDA
            hps_0_hps_io_hps_io_i2c1_inst_SCL                 : inout std_logic                     := 'X';             -- hps_io_i2c1_inst_SCL
            hps_0_hps_io_hps_io_gpio_inst_GPIO00              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO00
            hps_0_hps_io_hps_io_gpio_inst_GPIO09              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO09
            hps_0_hps_io_hps_io_gpio_inst_GPIO35              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO35
            hps_0_hps_io_hps_io_gpio_inst_GPIO48              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO48
            hps_0_hps_io_hps_io_gpio_inst_GPIO53              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO53
            hps_0_hps_io_hps_io_gpio_inst_GPIO54              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO54
            hps_0_hps_io_hps_io_gpio_inst_GPIO55              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO55
            hps_0_hps_io_hps_io_gpio_inst_GPIO56              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO56
            hps_0_hps_io_hps_io_gpio_inst_GPIO61              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO61
            hps_0_hps_io_hps_io_gpio_inst_GPIO62              : inout std_logic                     := 'X';             -- hps_io_gpio_inst_GPIO62
            led_pio_external_connection_in_port               : in    std_logic_vector(3 downto 0)  := (others => 'X'); -- in_port
            led_pio_external_connection_out_port              : out   std_logic_vector(3 downto 0);                     -- out_port
            dipsw_pio_external_connection_export              : in    std_logic_vector(3 downto 0)  := (others => 'X'); -- export
            button_pio_external_connection_export             : in    std_logic_vector(1 downto 0)  := (others => 'X'); -- export
            hps_0_h2f_reset_reset_n                           : out   std_logic;                                        -- reset_n
            hps_0_f2h_cold_reset_req_reset_n                  : in    std_logic                     := 'X';             -- reset_n
            hps_0_f2h_debug_reset_req_reset_n                 : in    std_logic                     := 'X';             -- reset_n
            hps_0_f2h_warm_reset_req_reset_n                  : in    std_logic                     := 'X';             -- reset_n
            hps_0_f2h_stm_hw_events_stm_hwevents              : in    std_logic_vector(27 downto 0) := (others => 'X'); -- stm_hwevents
            nios_slave_interface_0_avalon_slave_read          : out   std_logic;                                        -- read
            nios_slave_interface_0_avalon_slave_readdata      : in    std_logic_vector(31 downto 0) := (others => 'X'); -- readdata
            nios_slave_interface_0_avalon_slave_write         : out   std_logic;                                        -- write
            nios_slave_interface_0_avalon_slave_waitrequest   : in    std_logic                     := 'X';             -- waitrequest
            nios_slave_interface_0_avalon_slave_chipselect    : out   std_logic;                                        -- chipselect
            nios_slave_interface_0_avalon_slave_writedata     : out   std_logic_vector(31 downto 0);                    -- writedata
            nios_slave_interface_0_avalon_slave_address       : out   std_logic_vector(15 downto 0);                    -- address
            nios_slave_interface_0_avalon_slave_begintransfer : out   std_logic;                                        -- begintransfer
            nios_slave_interface_0_avalon_slave_byteenable    : out   std_logic_vector(3 downto 0);                     -- byteenable
            nios_slave_interface_0_reset_reset                : out   std_logic;                                        -- reset
            nios_slave_interface_0_interrupt_sender_irq       : in    std_logic                     := 'X';             -- irq
            lmk04826_spi_external_MISO                        : in    std_logic                     := 'X';             -- MISO
            lmk04826_spi_external_MOSI                        : out   std_logic;                                        -- MOSI
            lmk04826_spi_external_SCLK                        : out   std_logic;                                        -- SCLK
            lmk04826_spi_external_SS_n                        : out   std_logic;                                        -- SS_n
            ads34j45_spi_external_MISO                        : in    std_logic                     := 'X';             -- MISO
            ads34j45_spi_external_MOSI                        : out   std_logic;                                        -- MOSI
            ads34j45_spi_external_SCLK                        : out   std_logic;                                        -- SCLK
            ads34j45_spi_external_SS_n                        : out   std_logic;                                         -- SS_n
            ads_pdn_external_connection_export                : out   std_logic;                                        -- export
            ads_reset_external_connection_export              : out   std_logic                                         -- export
       	
	);
    end component soc_system;

component hps_reset is
	PORT
	(
		source_clk		: IN STD_LOGIC ;
		source		   : OUT STD_LOGIC_VECTOR (2 DOWNTO 0)
	);
end component hps_reset;
	 
	
-------------------------------------------------------------------------------------------
component edge_detect_2 is
        port (
            clk                                       : in    std_logic;                    
            rst_n                                     : in    std_logic;                    
            signal_in                                 : in    std_logic;                  
            pulse_out                                 : out   std_logic  
        );
end component edge_detect_2;
-------------------------------------------------------------------------------------------
component edge_detect_6 is
        port (
            clk                                       : in    std_logic;                    
            rst_n                                     : in    std_logic;                    
            signal_in                                 : in    std_logic;                  
            pulse_out                                 : out   std_logic  
        );
end component edge_detect_6;
---------------------------------------------------------------------------------------------
component edge_detect_32 is
        port (
            clk                                       : in    std_logic;                    
            rst_n                                     : in    std_logic;                    
            signal_in                                 : in    std_logic;                  
            pulse_out                                 : out   std_logic  
        );
end component edge_detect_32;
-----------------------------------------------------------------------------------------------

component count is
 
port  (     clk        : in std_logic;
            rst_n      : in std_logic;
            pulse_out  : out std_logic
      );
end component count;


-------------------------------------------------------------------------------------------------------

component GX_PLL_0002 is
		port (
			refclk   : in  std_logic := 'X'; -- clk
			rst      : in  std_logic := 'X'; -- reset
			outclk_0 : out std_logic;        -- clk
			outclk_1 : out std_logic;        -- clk
			locked   : out std_logic         -- export
		);
	end component GX_PLL_0002;
-----------------------------------------------------------------------------------------------------
	COMPONENT test_buf
	PORT (
			datain	: IN STD_LOGIC_VECTOR (0 DOWNTO 0);
			datain_b	: IN STD_LOGIC_VECTOR (0 DOWNTO 0);
			dataout	: OUT STD_LOGIC_VECTOR (0 DOWNTO 0)
	);
	END COMPONENT;
-----------------------------------------------------------------------------------------

 
  constant NO_LANES             : integer range 2 to 8 := 4;
  constant NO_CONVERTERS        : integer := 4;

  -----------------------------------------------------------------------------
  -- Misc
  -----------------------------------------------------------------------------
  signal reset                  : std_logic;
  signal hps_reset_req          : std_logic_vector(2 downto 0);
  -----------------------------------------------------------------------------
  -- JESD
  -----------------------------------------------------------------------------
  signal clk_device             : std_logic;
  signal clk_ref                : std_logic_vector(NO_LANES-1 downto 0);
  signal rx_serial_data         : std_logic_vector(NO_LANES-1 downto 0);
  signal tx_serial_data         : std_logic_vector(NO_LANES-1 downto 0);
  signal synchronize_out        : std_logic;
  -----------------------------------------------------------------------------
  -- Nios Slave interface
  -----------------------------------------------------------------------------
  signal cpu_clk                : std_logic;
  signal cpu_cs                 : std_logic;
  signal cpu_rd                 : std_logic;
  signal cpu_wr                 : std_logic;
  signal cpu_addr               : std_logic_vector(15 downto 0);
  signal cpu_wr_data            : std_logic_vector(31 downto 0);
  signal cpu_rd_data            : std_logic_vector(31 downto 0);
  signal cpu_reset              : std_logic;
  signal cpu_pio_reset          : std_logic;
  signal cpu_waitrequest        : std_logic;
  signal cpu_intr               : std_logic;
  signal cpu_byteenable         : std_logic_vector(3 downto 0);
  signal cpu_begintransfer      : std_logic;

--  signal pll_clk_150m           : std_logic;
  signal system_pll_locked      : std_logic;
  signal clk_ref_i              : std_logic;
  signal hsmc_clk_i             : std_logic;                          -- Input clock from hsmc
  signal sysref_out             : std_logic; 
  
  
  
  signal fpga_led_internal      : std_logic_vector(3 downto 0);
  signal fpga_led_internal_out  : std_logic_vector(3 downto 0);
  signal user_dipsw_fpga: std_logic_vector(3 downto 0);
  signal user_pb_fpga: std_logic_vector(1 downto 0);
  signal hps_fpga_reset_n: std_logic;
  signal hps_cold_reset: std_logic;
  signal hps_warm_reset: std_logic;
  signal hps_debug_reset: std_logic;
  signal stm_hw_events: std_logic_vector(27 downto 0);
  
  
  signal test0: std_logic;
  signal test1: std_logic;
  signal test2: std_logic;
  
  signal test3: std_logic;
  signal test4: std_logic;
  signal test5: std_logic;
   
  signal test_clk: std_logic;
  signal dataout_sig: std_logic_vector(0 downto 0);
  signal clk_lock: std_logic;
  
  signal hsmc_sig_p: std_logic_vector(0 downto 0);
  signal hsmc_sig_n: std_logic_vector(0 downto 0);
  
  signal lmk_data: std_logic_vector(2 downto 0);
  signal ads_data: std_logic_vector(2 downto 0);
  
  signal clk_test_out1: std_logic; 
  
  signal s_clk: std_logic;
  
begin

 -------------------------------------------------------------------
  -- Test LEDS (Not required)
  -------------------------------------------------------------------
   fpga_led_internal <= "0000";
	
	user1_leds(0) <= fpga_led_internal_out(0);
   user1_leds(1) <= lmk_data(0);
	user1_leds(2) <= test_clk;
	user1_leds(3) <= dataout_sig(0);



  -------------------------------------------------------------------
  -- QSYS
  -------------------------------------------------------------------
  	 u0 : component soc_system
        port map (
            clk_clk                               => clk_bot1,              --                            clk.clk
            reset_reset_n                         => hps_fpga_reset_n,      --                          reset.reset_n
            memory_mem_a                          => memory_mem_a,          --                         memory.mem_a
            memory_mem_ba                         => memory_mem_ba,         --                               .mem_ba
            memory_mem_ck                         => memory_mem_ck,         --                               .mem_ck
            memory_mem_ck_n                       => memory_mem_ck_n,       --                               .mem_ck_n
            memory_mem_cke                        => memory_mem_cke,        --                               .mem_cke
            memory_mem_cs_n                       => memory_mem_cs_n,       --                               .mem_cs_n
            memory_mem_ras_n                      => memory_mem_ras_n,      --                               .mem_ras_n
            memory_mem_cas_n                      => memory_mem_cas_n,      --                               .mem_cas_n
            memory_mem_we_n                       => memory_mem_we_n,       --                               .mem_we_n
            memory_mem_reset_n                    => memory_mem_reset_n,    --                               .mem_reset_n
            memory_mem_dq                         => memory_mem_dq,         --                               .mem_dq
            memory_mem_dqs                        => memory_mem_dqs,        --                               .mem_dqs
            memory_mem_dqs_n                      => memory_mem_dqs_n,      --                               .mem_dqs_n
            memory_mem_odt                        => memory_mem_odt,        --                               .mem_odt
            memory_mem_dm                         => memory_mem_dm,         --                               .mem_dm
            memory_oct_rzqin                      => memory_oct_rzqin,      --                               .oct_rzqin
            hps_0_hps_io_hps_io_emac1_inst_TX_CLK => hps_emac1_TX_CLK, --                   hps_0_hps_io.hps_io_emac1_inst_TX_CLK
            hps_0_hps_io_hps_io_emac1_inst_TXD0   => hps_emac1_TXD0,   --                               .hps_io_emac1_inst_TXD0
            hps_0_hps_io_hps_io_emac1_inst_TXD1   => hps_emac1_TXD1,   --                               .hps_io_emac1_inst_TXD1
            hps_0_hps_io_hps_io_emac1_inst_TXD2   => hps_emac1_TXD2,   --                               .hps_io_emac1_inst_TXD2
            hps_0_hps_io_hps_io_emac1_inst_TXD3   => hps_emac1_TXD3,   --                               .hps_io_emac1_inst_TXD3
            hps_0_hps_io_hps_io_emac1_inst_RXD0   => hps_emac1_RXD0,   --                               .hps_io_emac1_inst_RXD0
            hps_0_hps_io_hps_io_emac1_inst_MDIO   => hps_emac1_MDIO,   --                               .hps_io_emac1_inst_MDIO
            hps_0_hps_io_hps_io_emac1_inst_MDC    => hps_emac1_MDC,    --                               .hps_io_emac1_inst_MDC
            hps_0_hps_io_hps_io_emac1_inst_RX_CTL => hps_emac1_RX_CTL, --                               .hps_io_emac1_inst_RX_CTL
            hps_0_hps_io_hps_io_emac1_inst_TX_CTL => hps_emac1_TX_CTL, --                               .hps_io_emac1_inst_TX_CTL
            hps_0_hps_io_hps_io_emac1_inst_RX_CLK => hps_emac1_RX_CLK, --                               .hps_io_emac1_inst_RX_CLK
            hps_0_hps_io_hps_io_emac1_inst_RXD1   => hps_emac1_RXD1,   --                               .hps_io_emac1_inst_RXD1
            hps_0_hps_io_hps_io_emac1_inst_RXD2   => hps_emac1_RXD2,   --                               .hps_io_emac1_inst_RXD2
            hps_0_hps_io_hps_io_emac1_inst_RXD3   => hps_emac1_RXD3,   --                               .hps_io_emac1_inst_RXD3
            hps_0_hps_io_hps_io_qspi_inst_IO0     => hps_qspi_IO0,     --                               .hps_io_qspi_inst_IO0
            hps_0_hps_io_hps_io_qspi_inst_IO1     => hps_qspi_IO1,     --                               .hps_io_qspi_inst_IO1
            hps_0_hps_io_hps_io_qspi_inst_IO2     => hps_qspi_IO2,     --                               .hps_io_qspi_inst_IO2
            hps_0_hps_io_hps_io_qspi_inst_IO3     => hps_qspi_IO3,     --                               .hps_io_qspi_inst_IO3
            hps_0_hps_io_hps_io_qspi_inst_SS0     => hps_qspi_SS0,     --                               .hps_io_qspi_inst_SS0
            hps_0_hps_io_hps_io_qspi_inst_CLK     => hps_qspi_CLK,     --                               .hps_io_qspi_inst_CLK
            hps_0_hps_io_hps_io_sdio_inst_CMD     => hps_sdio_CMD,     --                               .hps_io_sdio_inst_CMD
            hps_0_hps_io_hps_io_sdio_inst_D0      => hps_sdio_D0,      --                               .hps_io_sdio_inst_D0
            hps_0_hps_io_hps_io_sdio_inst_D1      => hps_sdio_D1,      --                               .hps_io_sdio_inst_D1
            hps_0_hps_io_hps_io_sdio_inst_CLK     => hps_sdio_CLK,     --                               .hps_io_sdio_inst_CLK
            hps_0_hps_io_hps_io_sdio_inst_D2      => hps_sdio_D2,      --                               .hps_io_sdio_inst_D2
            hps_0_hps_io_hps_io_sdio_inst_D3      => hps_sdio_D3,      --                               .hps_io_sdio_inst_D3
            hps_0_hps_io_hps_io_usb1_inst_D0      => hps_usb1_D0,      --                               .hps_io_usb1_inst_D0
            hps_0_hps_io_hps_io_usb1_inst_D1      => hps_usb1_D1,      --                               .hps_io_usb1_inst_D1
            hps_0_hps_io_hps_io_usb1_inst_D2      => hps_usb1_D2,      --                               .hps_io_usb1_inst_D2
            hps_0_hps_io_hps_io_usb1_inst_D3      => hps_usb1_D3,      --                               .hps_io_usb1_inst_D3
            hps_0_hps_io_hps_io_usb1_inst_D4      => hps_usb1_D4,      --                               .hps_io_usb1_inst_D4
            hps_0_hps_io_hps_io_usb1_inst_D5      => hps_usb1_D5,      --                               .hps_io_usb1_inst_D5
            hps_0_hps_io_hps_io_usb1_inst_D6      => hps_usb1_D6,      --                               .hps_io_usb1_inst_D6
            hps_0_hps_io_hps_io_usb1_inst_D7      => hps_usb1_D7,      --                               .hps_io_usb1_inst_D7
            hps_0_hps_io_hps_io_usb1_inst_CLK     => hps_usb1_CLK,     --                               .hps_io_usb1_inst_CLK
            hps_0_hps_io_hps_io_usb1_inst_STP     => hps_usb1_STP,     --                               .hps_io_usb1_inst_STP
            hps_0_hps_io_hps_io_usb1_inst_DIR     => hps_usb1_DIR,     --                               .hps_io_usb1_inst_DIR
            hps_0_hps_io_hps_io_usb1_inst_NXT     => hps_usb1_NXT,     --                               .hps_io_usb1_inst_NXT
            hps_0_hps_io_hps_io_spim0_inst_CLK    => hps_spim0_CLK,    --                               .hps_io_spim0_inst_CLK
            hps_0_hps_io_hps_io_spim0_inst_MOSI   => hps_spim0_MOSI,   --                               .hps_io_spim0_inst_MOSI
            hps_0_hps_io_hps_io_spim0_inst_MISO   => hps_spim0_MISO,   --                               .hps_io_spim0_inst_MISO
            hps_0_hps_io_hps_io_spim0_inst_SS0    => hps_spim0_SS0,    --                               .hps_io_spim0_inst_SS0
            hps_0_hps_io_hps_io_spim1_inst_CLK    => hps_spim1_CLK,    --                               .hps_io_spim1_inst_CLK
            hps_0_hps_io_hps_io_spim1_inst_MOSI   => hps_spim1_MOSI,   --                               .hps_io_spim1_inst_MOSI
            hps_0_hps_io_hps_io_spim1_inst_MISO   => hps_spim1_MISO,   --                               .hps_io_spim1_inst_MISO
            hps_0_hps_io_hps_io_spim1_inst_SS0    => hps_spim1_SS0,    --                               .hps_io_spim1_inst_SS0
            hps_0_hps_io_hps_io_uart0_inst_RX     => hps_uart0_RX,     --                               .hps_io_uart0_inst_RX
            hps_0_hps_io_hps_io_uart0_inst_TX     => hps_uart0_TX,     --                               .hps_io_uart0_inst_TX
            hps_0_hps_io_hps_io_i2c1_inst_SDA     => hps_i2c1_SDA,     --                               .hps_io_i2c1_inst_SDA
            hps_0_hps_io_hps_io_i2c1_inst_SCL     => hps_i2c1_SCL,     --                               .hps_io_i2c1_inst_SCL
            hps_0_hps_io_hps_io_gpio_inst_GPIO00  => hps_gpio_GPIO00,  --                               .hps_io_gpio_inst_GPIO00
            hps_0_hps_io_hps_io_gpio_inst_GPIO09  => hps_gpio_GPIO09,  --                               .hps_io_gpio_inst_GPIO09
            hps_0_hps_io_hps_io_gpio_inst_GPIO35  => hps_gpio_GPIO35,  --                               .hps_io_gpio_inst_GPIO35
            hps_0_hps_io_hps_io_gpio_inst_GPIO48  => hps_gpio_GPIO48,  --                               .hps_io_gpio_inst_GPIO48
            hps_0_hps_io_hps_io_gpio_inst_GPIO53  => hps_gpio_GPIO53,  --                               .hps_io_gpio_inst_GPIO53
            hps_0_hps_io_hps_io_gpio_inst_GPIO54  => hps_gpio_GPIO54,  --                               .hps_io_gpio_inst_GPIO54
            hps_0_hps_io_hps_io_gpio_inst_GPIO55  => hps_gpio_GPIO55,  --                               .hps_io_gpio_inst_GPIO55
            hps_0_hps_io_hps_io_gpio_inst_GPIO56  => hps_gpio_GPIO56,  --                               .hps_io_gpio_inst_GPIO56
            hps_0_hps_io_hps_io_gpio_inst_GPIO61  => hps_gpio_GPIO61,  --                               .hps_io_gpio_inst_GPIO61
            hps_0_hps_io_hps_io_gpio_inst_GPIO62  => hps_gpio_GPIO62,  --                               .hps_io_gpio_inst_GPIO62
            led_pio_external_connection_in_port   => fpga_led_internal,		  
            led_pio_external_connection_out_port  => fpga_led_internal_out,   	
            dipsw_pio_external_connection_export  => user_dipsw_fpga,  
            button_pio_external_connection_export => user_pb_fpga,       
            hps_0_h2f_reset_reset_n               => hps_fpga_reset_n,          
            hps_0_f2h_cold_reset_req_reset_n      => not hps_cold_reset,      
            hps_0_f2h_debug_reset_req_reset_n     => not hps_debug_reset,    
            hps_0_f2h_warm_reset_req_reset_n      => not hps_warm_reset,
            hps_0_f2h_stm_hw_events_stm_hwevents  => stm_hw_events,    
				
				
				nios_slave_interface_0_avalon_slave_read          => cpu_rd,          
            nios_slave_interface_0_avalon_slave_readdata      => cpu_rd_data,      
            nios_slave_interface_0_avalon_slave_write         => cpu_wr,         
            nios_slave_interface_0_avalon_slave_waitrequest   => cpu_waitrequest,   
            nios_slave_interface_0_avalon_slave_chipselect    => cpu_cs,    
            nios_slave_interface_0_avalon_slave_writedata     => cpu_wr_data,     
            nios_slave_interface_0_avalon_slave_address       => cpu_addr,       
            nios_slave_interface_0_avalon_slave_begintransfer => cpu_begintransfer, 
            nios_slave_interface_0_avalon_slave_byteenable    => cpu_byteenable,    
            nios_slave_interface_0_reset_reset                => cpu_reset,                
            nios_slave_interface_0_interrupt_sender_irq       => '0',       
            lmk04826_spi_external_MISO                        => lmk_miso, 
            lmk04826_spi_external_MOSI                        => lmk_mosi,
            lmk04826_spi_external_SCLK                        => lmk_sclk,
            lmk04826_spi_external_SS_n                        => lmk_ssn,
            ads34j45_spi_external_MISO                        => ads_miso, 
            ads34j45_spi_external_MOSI                        => ads_mosi, 
            ads34j45_spi_external_SCLK                        => ads_sclk, 
            ads34j45_spi_external_SS_n                        => ads_ssn,
            ads_pdn_external_connection_export                => ads_pdn, 
            ads_reset_external_connection_export              => ads_reset
		  
		  );

  -------------------------------------------------------------------
  -- System PLL / Clock
  -------------------------------------------------------------------

  cpu_clk    <= clk_bot1;
  
  gx_pll_inst : component GX_PLL_0002
		port map (
			refclk   => HSMC_CLKIN2_P, 
			rst      => NOT cpu1_resetn,      
			outclk_0 => clk_device, 
			outclk_1 => s_clk,
			locked   => clk_lock     
		);
	
		-- Reference comes from Spare GX input!
 clk_ref(0)    <= HSMC_DEVCLK_P;--dataout_sig(0); -- External Programmed 100 MHz clock
 clk_ref(1)    <= HSMC_DEVCLK_P;--dataout_sig(0); -- External Programmed 100 MHz clock
 clk_ref(2)    <= HSMC_DEVCLK_P;--dataout_sig(0); -- External Programmed 100 MHz clock
 clk_ref(3)    <= HSMC_DEVCLK_P;--dataout_sig(0); -- External Programmed 100 MHz clock

   -------------------------------------------------------------------
  -- Concatenate Incoming ADC Data into a single bus
  -------------------------------------------------------------------
  rx_serial_data <= ( HSMC_GXB_RX3_P & HSMC_GXB_RX2_P & HSMC_GXB_RX1_P & HSMC_GXB_RX0_P);
   
  -------------------------------------------------------------------
  -- Sync signals
  -------------------------------------------------------------------	 
	  
	 LMK_SYNC <= synchronize_out;
	 ADS_SYNC_P <= NOT synchronize_out;
	 
	------------------------------------------------------------------

  -------------------------------------------------------------------
  -- JESD eval core
  -------------------------------------------------------------------
  eval_core : entity work.jesd204b_eval_core
  generic map(
    SIMULATION         => false,
    NO_LANES           => NO_LANES,
    NO_CONVERTERS      => NO_CONVERTERS
  )
  port map (
    clk_device         => clk_device,
	 s_clk              => s_clk,
    sync_b_out         => synchronize_out,
    sync_b_in          => '0',
    sysref_in          => HSMC_SYSREF_P,
    sysref_out         => sysref_out,
    clk_ref            => clk_ref,
    rx_serial_data     => rx_serial_data(NO_LANES-1 downto 0),
    system_pll_locked  => system_pll_locked,
    -- CPU clock/reset
    cpu_clk            => cpu_clk,
    cpu_reset          => cpu_reset,
    -- CPU interface
    cpu_address        => cpu_addr,
    cpu_wr_data        => cpu_wr_data,
    cpu_rd_data        => cpu_rd_data,
    cpu_read           => cpu_rd,
    cpu_write          => cpu_wr,
    cpu_select         => cpu_cs,
    cpu_waitrequest    => cpu_waitrequest,
    cpu_intr           => cpu_intr,
    -- ADI SPI i/f
    spi_di             => '0',
    spi_do             => open,
    spi_do_en          => open,
    spi_clk            => open,
    spi_cs_n           => open,
	 test_clk           => test_clk,
    -- SFP+ status
    sfp_mod_abs        => (others=>'0'),
    sfp_op_los         => (others=>'0'),
    sfp_op_tx_flt      => (others=>'0'),
	 trigger_in         => fpga_led_internal_out(0)
  );


hps_reset_inst : hps_reset PORT MAP (
		source_clk	 => clk_bot1,
		source	 => hps_reset_req
	);



 	 u2 : component edge_detect_2
        port map (
            clk                              => clk_bot1,              
            rst_n                            => hps_fpga_reset_n,      
            signal_in                        => hps_reset_req(1),         
            pulse_out                        => hps_warm_reset         
 	  );


 	 u3 : component edge_detect_6
        port map (
            clk                              => clk_bot1,              
            rst_n                            => hps_fpga_reset_n,      
            signal_in                        => hps_reset_req(0),          
            pulse_out                        => hps_cold_reset         
 	  );


 	 u4 : component edge_detect_32
        port map (
            clk                              => clk_bot1,              
            rst_n                            => hps_fpga_reset_n,      
            signal_in                        => hps_reset_req(2),          
            pulse_out                        => hps_debug_reset         
 	  );


end rtl;
